<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "North Dakota";
    var qsoPartyUrl = "http://w0nd.com/ndqso14.pdf";
    var overlayUrl = "http://www.no5w.com/OverlayNorthDakotaRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Adams", "adm");
  countySelection.options[1] = new Option("Barnes", "brn");
  countySelection.options[2] = new Option("Benson", "bsn");
  countySelection.options[3] = new Option("Billings", "bll");
  countySelection.options[4] = new Option("Bottineau", "bot");
  countySelection.options[5] = new Option("Bowman", "bow");
  countySelection.options[6] = new Option("Burke", "brk");
  countySelection.options[7] = new Option("Burleigh", "bur");
  countySelection.options[8] = new Option("Cass", "css");
  countySelection.options[9] = new Option("Cavalier", "cav");
  countySelection.options[10] = new Option("Dickey", "dik");
  countySelection.options[11] = new Option("Divide", "div");
  countySelection.options[12] = new Option("Dunn", "dun");
  countySelection.options[13] = new Option("Eddy", "edy");
  countySelection.options[14] = new Option("Emmons", "emn");
  countySelection.options[15] = new Option("Foster", "fos");
  countySelection.options[16] = new Option("GoldenValley", "gnv");
  countySelection.options[17] = new Option("GrandForks", "gfk");
  countySelection.options[18] = new Option("Grant", "gnt");
  countySelection.options[19] = new Option("Griggs", "grg");
  countySelection.options[20] = new Option("Hettinger", "het");
  countySelection.options[21] = new Option("Kidder", "kdr");
  countySelection.options[22] = new Option("LaMoure", "lmr");
  countySelection.options[23] = new Option("Logan", "log");
  countySelection.options[24] = new Option("McHenry", "mch");
  countySelection.options[25] = new Option("McIntosh", "mci");
  countySelection.options[26] = new Option("McKenzie", "mck");
  countySelection.options[27] = new Option("McLean", "mcl");
  countySelection.options[28] = new Option("Mercer", "mcr");
  countySelection.options[29] = new Option("Morton", "mtn");
  countySelection.options[30] = new Option("Mountrail", "mrl");
  countySelection.options[31] = new Option("Nelson", "nel");
  countySelection.options[32] = new Option("Oliver", "olr");
  countySelection.options[33] = new Option("Pembina", "pba");
  countySelection.options[34] = new Option("Pierce", "prc");
  countySelection.options[35] = new Option("Ramsey", "rmy");
  countySelection.options[36] = new Option("Ransom", "rsm");
  countySelection.options[37] = new Option("Renville", "ren");
  countySelection.options[38] = new Option("Richland", "rld");
  countySelection.options[39] = new Option("Rolette", "rol");
  countySelection.options[40] = new Option("Sargent", "sgt");
  countySelection.options[41] = new Option("Sheridan", "srn");
  countySelection.options[42] = new Option("Sioux", "six");
  countySelection.options[43] = new Option("Slope", "slp");
  countySelection.options[44] = new Option("Stark", "stk");
  countySelection.options[45] = new Option("Steele", "stl");
  countySelection.options[46] = new Option("Stutsman", "stn");
  countySelection.options[47] = new Option("Towner", "twr");
  countySelection.options[48] = new Option("Traill", "trl");
  countySelection.options[49] = new Option("Walsh", "wlh");
  countySelection.options[50] = new Option("Ward", "wrd");
  countySelection.options[51] = new Option("Wells", "wls");
  countySelection.options[52] = new Option("Williams", "wlm");
  addMarker(46.11380000, -102.49700000, "Adams", "adm");
  addMarker(46.93560000, -98.07450000, "Barnes", "brn");
  addMarker(48.10880000, -99.18680000, "Benson", "bsn");
  addMarker(46.97950000, -103.35000000, "Billings", "bll");
  addMarker(48.77210000, -100.82100000, "Bottineau", "bot");
  addMarker(46.11280000, -103.52100000, "Bowman", "bow");
  addMarker(48.77270000, -102.48100000, "Burke", "brk");
  addMarker(46.98050000, -100.52000000, "Burleigh", "bur");
  addMarker(46.93460000, -97.23270000, "Cass", "css");
  addMarker(48.77180000, -98.46410000, "Cavalier", "cav");
  addMarker(46.10960000, -98.50600000, "Dickey", "dik");
  addMarker(48.81650000, -103.46700000, "Divide", "div");
  addMarker(47.40210000, -102.62200000, "Dunn", "dun");
  addMarker(47.71740000, -98.89870000, "Eddy", "edy");
  addMarker(46.28830000, -100.27000000, "Emmons", "emn");
  addMarker(47.45720000, -98.88280000, "Foster", "fos");
  addMarker(46.93550000, -103.82800000, "GoldenValley", "gnv");
  addMarker(47.93350000, -97.39740000, "GrandForks", "gfk");
  addMarker(46.36350000, -101.56000000, "Grant", "gnt");
  addMarker(47.45650000, -98.23040000, "Griggs", "grg");
  addMarker(46.41800000, -102.46300000, "Hettinger", "het");
  addMarker(46.97950000, -99.78070000, "Kidder", "kdr");
  addMarker(46.45690000, -98.53550000, "LaMoure", "lmr");
  addMarker(46.45780000, -99.47700000, "Logan", "log");
  addMarker(48.24020000, -100.62900000, "McHenry", "mch");
  addMarker(46.11170000, -99.44160000, "McIntosh", "mci");
  addMarker(47.73750000, -103.29800000, "McKenzie", "mck");
  addMarker(47.50270000, -101.48500000, "McLean", "mcl");
  addMarker(47.27780000, -101.73100000, "Mercer", "mcr");
  addMarker(46.63350000, -101.32000000, "Morton", "mtn");
  addMarker(48.14930000, -102.37900000, "Mountrail", "mrl");
  addMarker(47.93360000, -98.20410000, "Nelson", "nel");
  addMarker(47.13870000, -101.32200000, "Oliver", "olr");
  addMarker(48.77150000, -97.52410000, "Pembina", "pba");
  addMarker(48.19630000, -99.88490000, "Pierce", "prc");
  addMarker(48.22950000, -98.74630000, "Ramsey", "rmy");
  addMarker(46.45650000, -97.65740000, "Ransom", "rsm");
  addMarker(48.72910000, -101.54100000, "Renville", "ren");
  addMarker(46.28330000, -96.91760000, "Richland", "rld");
  addMarker(48.77210000, -99.83810000, "Rolette", "rol");
  addMarker(46.10890000, -97.61830000, "Sargent", "sgt");
  addMarker(47.58740000, -100.35300000, "Sheridan", "srn");
  addMarker(46.18650000, -101.25300000, "Sioux", "six");
  addMarker(46.45500000, -103.48500000, "Slope", "slp");
  addMarker(46.82010000, -102.66400000, "Stark", "stk");
  addMarker(47.45560000, -97.71900000, "Steele", "stl");
  addMarker(46.97880000, -98.96000000, "Stutsman", "stn");
  addMarker(48.68520000, -99.24830000, "Towner", "twr");
  addMarker(47.45490000, -97.15360000, "Traill", "trl");
  addMarker(48.36870000, -97.71760000, "Walsh", "wlh");
  addMarker(48.32700000, -101.60200000, "Ward", "wrd");
  addMarker(47.58740000, -99.66770000, "Wells", "wls");
  addMarker(48.29500000, -103.43800000, "Williams", "wlm");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

